@@ -102,7 +102,7 @@ void KGpgExternalActions::slotEncryptionKeySelected()
 		eopt |= KGpgEncrypt::HideKeyId;
 
 	if (KGpgSettings::allowCustomEncryptionOptions()) {
-		const QString customopts(dialog->getCustomOptions().isEmpty());
+		const QString customopts = dialog->getCustomOptions();
 
 		if (!customopts.isEmpty())
 #if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
@@ -413,7 +413,7 @@ void KGpgExternalActions::slotDecryptionDone(int status)
 	} else {
 		if (!m_decryptionFailed.isEmpty()) {
 			QStringList failedFiles;
-			for (const QUrl &url : m_decryptionFailed)
+			for (const QUrl &url : qAsConst(m_decryptionFailed))
 				failedFiles.append(url.toDisplayString());
 			KMessageBox::errorList(nullptr,
 					i18np("Decryption of this file failed:", "Decryption of these files failed:",
